//-----------------------------------------------------------------------
//	File:		$RCSfile: Lab1Testbench.v,v $
//	Version:	$Revision: 1.1 $
//	Desc:		Testbench for Lab1
//	Author:		Greg Gibeling
//	Copyright:	Copyright 2003-2005 UC Berkeley
//	This copyright header must appear in all derivative works.
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Section:	Change Log
//-----------------------------------------------------------------------
//	$Log: Lab1Testbench.v,v $
//	Revision 1.1  2005/01/17 22:47:40  gdgib
//	Finished modifications from Fall 2004
//	Fully Tested
//	
//	Revision 1.4  2004/07/08 18:39:31  Administrator
//	Fixed formatting typos
//	
//	Revision 1.3  2004/07/02 23:44:11  Administrator
//	Added ActiveCycles macro to support timing simulation
//	
//	Revision 1.2  2004/07/02 20:32:18  Administrator
//	Changed module name to match filename
//	
//	Revision 1.1  2004/07/02 03:05:15  Administrator
//	Initial Import
//	Not tested
//	
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Section:	Defines and Constants
//-----------------------------------------------------------------------
`timescale		1 ns/1 ps		// Display things in ns, compute them in ps
`define HalfCycle	18.518			// Half of the clock cycle time in nanoseconds
`define Cycle		(`HalfCycle * 2)	// Didn't you learn to multiply?
`define ActiveCycles	16			// Change this to hold the buttons down for longer!
//-----------------------------------------------------------------------

//-----------------------------------------------------------------------
//	Module:		Lab1Testbench
//	CUT:		FPGA_TOP2, Lab1Circuit
//-----------------------------------------------------------------------
module Lab1Testbench;
	//---------------------------------------------------------------
	//	Wires and Regs
	//---------------------------------------------------------------
	reg			ClockPin, ResetPin, EnablePin;	// Raw Signals, generated by this testbench

	reg	[7:0]		In;				// Raw Signal, generated by this testbench
	wire	[19:0]		PINOUT_BOTTOM_CLOSE;		// This contains the output from the Lab1Circuit
	wire	[7:0]		Out;				// The actual binary output of the Lab1Circuit
	wire			Enable, Reset;			// The parsed, clean versions of ResetPin and EnablePin
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	CUT:	FPGA_TOP2
	//		This section instantiate the CUT or Circuit Under
	//		Test.  Notice that we are not connecting most of
	//		the I/O ports of FPGA_TOP2.  This is because they
	//		are not relevant to this simulation.
	//---------------------------------------------------------------
	FPGA_TOP2	CUT(	.Y5_CLK(		ClockPin),			// Connect the Clock
				.SW_(			{6'h3F, EnablePin, ResetPin}),	// Connect the Reset and Enable signals
				.SW9_(			~In),				// Connect the Input (Notice the inverter!!)
				.PINOUT_BOTTOM_CLOSE(	PINOUT_BOTTOM_CLOSE));		// Get the Output
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Assigns
	//---------------------------------------------------------------
	assign		Enable =			PINOUT_BOTTOM_CLOSE[9];		// Extract the Enable signal from the PINOUT_BOTTOM_CLOSE bus
	assign		Reset =				PINOUT_BOTTOM_CLOSE[8];		// Extract the Reset signal from the PINOUT_BOTTOM_CLOSE bus
	assign		Out =				PINOUT_BOTTOM_CLOSE[7:0];	// Extract the Out signal from the PINOUT_BOTTOM_CLOSE bus
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Clock Source
	//		This section will generate a clock signal,
	//		turning it on and off according the HalfCycle
	//		time, in this case it will generate a 27MHz clock
	//		THIS COULD NEVER BE SYNTHESIZED
	//---------------------------------------------------------------
	initial ClockPin =		1'b0;		// We need to start at 1'b0, otherwise clock will always be 1'bx
	always #(`HalfCycle) ClockPin =	~ClockPin;	// Every half clock cycle, invert the clock
	//---------------------------------------------------------------

	//---------------------------------------------------------------
	//	Test Stimulus
	//		This initial block will periodically set new
	//		values for the inputs to the CUT.  By changing
	//		the values we can pretend that the circuit is on
	//		a CaLinx2 board and you are pressing the buttons.
	//		THIS COULD NEVER BE SYNTHESIZED
	//---------------------------------------------------------------
	initial begin
		In =			8'h01;	// Set the input value
		EnablePin =		1'b1;	// We're not currently pressing the enable button (active low)
		ResetPin =		1'b1;	// We're not currently pressing the reset button (active low)
		#(`Cycle * 20);			// Let 20 clock cycles go by...
						// This is important for the post place and route simulation
		ResetPin =		1'b0;	// Press the reset button (active low)
		#(`Cycle * `ActiveCycles);	// Hold it down so that it can be seen
		ResetPin =		1'b1;	// Let go of the reset button

		// You should be able to figure out what's going on from here...
		#(`Cycle * `ActiveCycles);

		EnablePin =		1'b0;
		#(`Cycle * `ActiveCycles);
		EnablePin =		1'b1;

		#(`Cycle * `ActiveCycles);

		In =			8'h12;
		EnablePin =		1'b0;
		#(`Cycle * `ActiveCycles);
		EnablePin =		1'b1;

		#(`Cycle * `ActiveCycles);

		In =			8'hA0;
		EnablePin =		1'b0;
		#(`Cycle * `ActiveCycles);
		EnablePin =		1'b1;
	end
	//---------------------------------------------------------------
endmodule
//-----------------------------------------------------------------------